@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AdminSysConfig.pm - to change ConfigParameter
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: AdminSysConfig.pm,v 1.56 2006/10/12 10:09:41 martin Exp $
+# $Id: AdminSysConfig.pm,v 1.58.2.2 2007/02/26 14:24:01 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -15,7 +15,7 @@ use strict;
 use Kernel::System::Config;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.56 $';
+$VERSION = '$Revision: 1.58.2.2 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -464,7 +464,7 @@ sub Run {
             $Output .= $Self->{LayoutObject}->Notify(
                 Priority => 'Error',
                 Data => '$Text{"Security Note: You should activate %s because application is already running!", "SecureMode"}',
-                Link => '$Env{"Baselink"}Action=AdminSysConfig&Subaction=Edit&SysConfigGroup=Framework&SysConfigSubGroup=Core"',
+                Link => '$Env{"Baselink"}Action=AdminSysConfig&Subaction=Edit&SysConfigGroup=Framework&SysConfigSubGroup=Core',
             );
         }
         $Output .= $Self->{LayoutObject}->Output(TemplateFile => 'AdminSysConfigEdit', Data => \%Data);
@@ -516,6 +516,13 @@ sub Run {
         Name     => 'SysConfigGroup',
         LanguageTranslation => 0,
     );
+    # check if sysconfig download link should be shown
+    if ($Self->{SysConfigObject}->Download()) {
+        $Self->{LayoutObject}->Block(
+            Name => 'Download',
+            Data => { },
+        );
+    }
 
     my $Output .= $Self->{LayoutObject}->Header(Value => $Group);
     $Output .= $Self->{LayoutObject}->NavigationBar();
@@ -523,7 +530,7 @@ sub Run {
         $Output .= $Self->{LayoutObject}->Notify(
             Priority => 'Error',
             Data => '$Text{"Security Note: You should activate %s because application is already running!", "SecureMode"}',
-            Link => '$Env{"Baselink"}Action=AdminSysConfig&Subaction=Edit&SysConfigGroup=Framework&SysConfigSubGroup=Core"',
+            Link => '$Env{"Baselink"}Action=AdminSysConfig&Subaction=Edit&SysConfigGroup=Framework&SysConfigSubGroup=Core',
         );
     }
     $Output .= $Self->{LayoutObject}->Output(
@@ -727,7 +734,6 @@ sub ListConfigItem {
     }
     # ConfigElement FrontendModuleReg
     elsif (defined ($ItemHash{Setting}[1]{FrontendModuleReg})) {
-#    $Self->{LogObject}->Dumper(fdsa => $ItemHash{Setting}[1]{FrontendModuleReg});
         my %Data = ();
         foreach my $Key (qw(Title Description NavBarName)) {
             $Data{'Key'.$Key} = $Key;
@@ -922,7 +928,7 @@ sub ListConfigItem {
                     $ArrayHours[$ItemHash{Setting}[1]{TimeWorkingHours}[1]{Day}[$Index]{Hour}[$Index2]{Content}] = 'checked';
                 }
             }
-            foreach my $Z (1...24) {
+            foreach my $Z (0...23) {
                 $Self->{LayoutObject}->Block(
                     Name => 'ConfigElementTimeWorkingHoursHours',
                     Data => {
