@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AgentTicketPhone.pm - to handle phone calls
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: AgentTicketPhone.pm,v 1.24 2006/09/29 16:33:47 mh Exp $
+# $Id: AgentTicketPhone.pm,v 1.28.2.2 2007/03/02 00:09:47 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -20,7 +20,7 @@ use Kernel::System::State;
 use Mail::Address;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.24 $';
+$VERSION = '$Revision: 1.28.2.2 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -68,6 +68,7 @@ sub Run {
     foreach (qw(AttachmentUpload ArticleID PriorityID NewUserID
         From Subject Body NextStateID TimeUnits
         Year Month Day Hour Minute
+        NewResponsibleID ResponsibleAll OwnerAll
         AttachmentDelete1 AttachmentDelete2 AttachmentDelete3 AttachmentDelete4
         AttachmentDelete5 AttachmentDelete6 AttachmentDelete7 AttachmentDelete8
         AttachmentDelete9 AttachmentDelete10 AttachmentDelete11 AttachmentDelete12
@@ -113,9 +114,9 @@ sub Run {
                 Value => $Self->{RequestedURL},
             );
         }
-        # --
+
         # get split article if given
-        # --
+
         # get ArticleID
         my %Article = ();
         my %CustomerData = ();
@@ -256,18 +257,18 @@ sub Run {
         }
         my $Dest = $Self->{ParamObject}->GetParam(Param => 'Dest') || '';
         my ($NewQueueID, $To) = split(/\|\|/, $Dest);
-        my $AllUsers = $Self->{ParamObject}->GetParam(Param => 'AllUsers') || '';
-        if (!$NewQueueID) {
-            $AllUsers = 1;
-        }
         my $CustomerUser = $Self->{ParamObject}->GetParam(Param => 'CustomerUser') ||
             $Self->{ParamObject}->GetParam(Param => 'PreSelectedCustomerUser') ||
             $Self->{ParamObject}->GetParam(Param => 'SelectedCustomerUser') || '';
         my $SelectedCustomerUser = $Self->{ParamObject}->GetParam(Param => 'SelectedCustomerUser') || '';
         my $CustomerID = $Self->{ParamObject}->GetParam(Param => 'CustomerID') || '';
         my $ExpandCustomerName = $Self->{ParamObject}->GetParam(Param => 'ExpandCustomerName') || 0;
-        if ($Self->{ParamObject}->GetParam(Param => 'AllUsersRefresh')) {
-            $AllUsers = 1;
+        if ($Self->{ParamObject}->GetParam(Param => 'OwnerAllRefresh')) {
+            $GetParam{OwnerAll} = 1;
+            $ExpandCustomerName = 3;
+        }
+        if ($Self->{ParamObject}->GetParam(Param => 'ResponsibleAllRefresh')) {
+            $GetParam{ResponsibleAll} = 1;
             $ExpandCustomerName = 3;
         }
         if ($Self->{ParamObject}->GetParam(Param => 'ClearFrom')) {
@@ -440,9 +441,8 @@ sub Run {
         elsif ($ExpandCustomerName == 4) {
             $Error{NoSubmit} = 1;
         }
-        # --
+
         # show customer info
-        # --
         my %CustomerData = ();
         if ($Self->{ConfigObject}->Get('Ticket::Frontend::CustomerInfoCompose')) {
             if ($CustomerUser || $SelectedCustomerUser) {
@@ -456,9 +456,8 @@ sub Run {
                 );
             }
         }
-        # --
+
         # check some values
-        # --
         foreach my $Email (Mail::Address->parse($GetParam{From})) {
             if (!$Self->{CheckItemObject}->CheckEmail(Address => $Email->address())) {
                 $Error{"From invalid"} .= $Self->{CheckItemObject}->CheckError();
@@ -474,23 +473,21 @@ sub Run {
             $Error{"Destination invalid"} = 'invalid';
         }
         if (%Error) {
-            # --
+
             # header
-            # --
             my $Output = $Self->{LayoutObject}->Header();
             $Output .= $Self->{LayoutObject}->NavigationBar();
-            # --
+
             # html output
-            # --
             $Output .= $Self->_MaskPhoneNew(
                 QueueID => $Self->{QueueID},
-                Users => $Self->_GetUsers(QueueID => $NewQueueID, AllUsers => $AllUsers),
+                Users => $Self->_GetUsers(QueueID => $NewQueueID, AllUsers => $GetParam{OwnerAll}),
                 UserSelected => $GetParam{NewUserID},
-                ResponsibleUsers => $Self->_GetUsers(QueueID => $NewQueueID, AllUsers => $AllUsers),
+                ResponsibleUsers => $Self->_GetUsers(QueueID => $NewQueueID, AllUsers => $GetParam{ResponsibleAll}),
                 ResponsibleUserSelected => $GetParam{NewResponsibleID},
-                NextStates => $Self->_GetNextStates(QueueID => $NewQueueID),
+                NextStates => $Self->_GetNextStates(QueueID => $NewQueueID || 1),
                 NextState => $NextState,
-                Priorities => $Self->_GetPriorities(QueueID => $NewQueueID),
+                Priorities => $Self->_GetPriorities(QueueID => $NewQueueID || 1),
                 CustomerID => $Self->{LayoutObject}->Ascii2Html(Text => $CustomerID),
                 CustomerUser => $CustomerUser,
                 CustomerData => \%CustomerData,
@@ -636,6 +633,7 @@ sub Run {
                 );
                 $Self->{TicketObject}->TicketFreeTimeSet(
                     %Time,
+                    Prefix => "TicketFreeTime",
                     TicketID => $TicketID,
                     Counter => $_,
                     UserID => $Self->{UserID},
@@ -696,6 +694,14 @@ sub Run {
                     UserID => $Self->{UserID},
                 );
             }
+            # set responsible (if new user id is given)
+            if ($GetParam{NewResponsibleID}) {
+                $Self->{TicketObject}->ResponsibleSet(
+                    TicketID => $TicketID,
+                    NewUserID => $GetParam{NewResponsibleID},
+                    UserID => $Self->{UserID},
+                );
+            }
             # time accounting
             if ($GetParam{TimeUnits}) {
                 $Self->{TicketObject}->TicketAccountTime(
@@ -909,12 +915,6 @@ sub _MaskPhoneNew {
         SelectedID => $Param{UserSelected},
         Name => 'NewUserID',
     );
-    $Param{ResponsibleUsers}->{''} = '-';
-    $Param{'ResponsibleOptionStrg'} = $Self->{LayoutObject}->OptionStrgHashRef(
-        Data => $Param{ResponsibleUsers},
-        SelectedID => $Param{ResponsibleUserSelected},
-        Name => 'NewResponsibleID',
-    );
     # build next states string
     $Param{'NextStatesStrg'} = $Self->{LayoutObject}->OptionStrgHashRef(
         Data => $Param{NextStates},
@@ -1015,7 +1015,14 @@ sub _MaskPhoneNew {
         }
     }
     # show responsible selection
-    if ($Self->{ConfigObject}->Get('Ticket::Frontend::NewResponsibleSelection')) {
+    if ($Self->{ConfigObject}->Get('Ticket::Responsible') &&
+        $Self->{ConfigObject}->Get('Ticket::Frontend::NewResponsibleSelection')) {
+        $Param{ResponsibleUsers}->{''} = '-';
+        $Param{'ResponsibleOptionStrg'} = $Self->{LayoutObject}->OptionStrgHashRef(
+            Data => $Param{ResponsibleUsers},
+            SelectedID => $Param{ResponsibleUserSelected},
+            Name => 'NewResponsibleID',
+        );
         $Self->{LayoutObject}->Block(
             Name => 'ResponsibleSelection',
             Data => \%Param,
