@@ -2,7 +2,7 @@
 # Kernel/System/DB/mysql.pm - mysql database backend
 # Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
 # --
-# $Id: mysql.pm,v 1.8 2006/08/29 17:31:42 martin Exp $
+# $Id: mysql.pm,v 1.11 2006/11/30 11:33:04 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,9 +14,24 @@ package Kernel::System::DB::mysql;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.8 $';
+$VERSION = '$Revision: 1.11 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
+sub new {
+    my $Type = shift;
+    my %Param = @_;
+
+    # allocate new hash for object
+    my $Self = {};
+    bless ($Self, $Type);
+
+    # check needed objects
+    foreach (keys %Param) {
+        $Self->{$_} = $Param{$_};
+    }
+    return $Self;
+}
+
 sub LoadPreferences {
     my $Self = shift;
     my %Param = @_;
@@ -35,6 +50,24 @@ sub LoadPreferences {
 
     return 1;
 }
+
+sub Quote {
+    my $Self = shift;
+    my $Text = shift;
+    if (defined(${$Text})) {
+        if ($Self->{'DB::QuoteBack'}) {
+            ${$Text} =~ s/\\/$Self->{'DB::QuoteBack'}\\/g;
+        }
+        if ($Self->{'DB::QuoteSingle'}) {
+            ${$Text} =~ s/'/$Self->{'DB::QuoteSingle'}'/g;
+        }
+        if ($Self->{'DB::QuoteSemicolon'}) {
+            ${$Text} =~ s/;/$Self->{'DB::QuoteSemicolon'};/g;
+        }
+    }
+    return $Text;
+}
+
 sub DatabaseCreate {
     my $Self = shift;
     my %Param = @_;
@@ -46,6 +79,7 @@ sub DatabaseCreate {
     # return SQL
     return ("CREATE DATABASE $Param{Name}");
 }
+
 sub DatabaseDrop {
     my $Self = shift;
     my %Param = @_;
@@ -57,6 +91,7 @@ sub DatabaseDrop {
     # return SQL
     return ("DROP DATABASE IF EXISTS $Param{Name}");
 }
+
 sub TableCreate {
     my $Self = shift;
     my @Param = @_;
@@ -199,6 +234,7 @@ sub TableCreate {
     }
     return @Return;
 }
+
 sub TableDrop {
     my $Self = shift;
     my @Param = @_;
@@ -214,6 +250,7 @@ sub TableDrop {
     }
     return ();
 }
+
 sub TableAlter {
     my $Self = shift;
     my @Param = @_;
@@ -250,6 +287,7 @@ sub TableAlter {
     }
     return @SQL;
 }
+
 sub IndexCreate {
     my $Self = shift;
     my %Param = @_;
@@ -276,6 +314,7 @@ sub IndexCreate {
     return ($SQL);
 
 }
+
 sub IndexDrop {
     my $Self = shift;
     my %Param = @_;
@@ -289,6 +328,7 @@ sub IndexDrop {
     my $SQL = "DROP INDEX $Param{Name}";
     return ($SQL);
 }
+
 sub ForeignKeyCreate {
     my $Self = shift;
     my %Param = @_;
@@ -305,6 +345,7 @@ sub ForeignKeyCreate {
     # return SQL
     return ($SQL);
 }
+
 sub ForeignKeyDrop {
     my $Self = shift;
     my %Param = @_;
@@ -318,6 +359,7 @@ sub ForeignKeyDrop {
 #    my $SQL = "ALTER TABLE $Param{TableName} DROP CONSTRAINT $Param{Name}";
 #    return ($SQL);
 }
+
 sub UniqueCreate {
     my $Self = shift;
     my %Param = @_;
@@ -341,6 +383,7 @@ sub UniqueCreate {
     return ($SQL);
 
 }
+
 sub UniqueDrop {
     my $Self = shift;
     my %Param = @_;
@@ -354,6 +397,7 @@ sub UniqueDrop {
     my $SQL = "ALTER TABLE $Param{TableName} DROP CONSTRAINT $Param{Name}";
     return ($SQL);
 }
+
 sub Insert {
     my $Self = shift;
     my @Param = @_;
@@ -365,13 +409,13 @@ sub Insert {
             $SQL = "INSERT INTO $Tag->{Table} "
         }
         if ($Tag->{Tag} eq 'Data' && $Tag->{TagType} eq 'Start') {
-            $Tag->{Key} = $Self->Quote($Tag->{Key});
+            $Tag->{Key} = ${$Self->Quote(\$Tag->{Key})};
             push (@Keys, $Tag->{Key});
             if ($Tag->{Type} && $Tag->{Type} eq 'Quote') {
-                $Tag->{Value} = "'".$Self->Quote($Tag->{Value})."'";
+                $Tag->{Value} = "'".${$Self->Quote(\$Tag->{Value})}."'";
             }
             else {
-                $Tag->{Value} = $Self->Quote($Tag->{Value});
+                $Tag->{Value} = ${$Self->Quote(\$Tag->{Value})};
             }
             push (@Values, $Tag->{Value});
         }
@@ -393,6 +437,7 @@ sub Insert {
     $SQL .= "($Key) VALUES ($Value)";
     return ($SQL);
 }
+
 sub _TypeTranslation {
     my $Self = shift;
     my $Tag = shift;
@@ -418,4 +463,5 @@ sub _TypeTranslation {
     }
     return $Tag;
 }
+
 1;
