@@ -1,8 +1,8 @@
 # --
 # Kernel/System/DB/oracle.pm - oracle database backend
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: oracle.pm,v 1.14 2006/10/04 11:13:49 martin Exp $
+# $Id: oracle.pm,v 1.17.2.1 2007/01/30 15:11:52 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,9 +14,24 @@ package Kernel::System::DB::oracle;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.14 $';
+$VERSION = '$Revision: 1.17.2.1 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
+sub new {
+    my $Type = shift;
+    my %Param = @_;
+
+    # allocate new hash for object
+    my $Self = {};
+    bless ($Self, $Type);
+
+    # check needed objects
+    foreach (keys %Param) {
+        $Self->{$_} = $Param{$_};
+    }
+    return $Self;
+}
+
 sub LoadPreferences {
     my $Self = shift;
     my %Param = @_;
@@ -39,6 +54,23 @@ sub LoadPreferences {
     return 1;
 }
 
+sub Quote {
+    my $Self = shift;
+    my $Text = shift;
+    if (defined(${$Text})) {
+        if ($Self->{'DB::QuoteBack'}) {
+            ${$Text} =~ s/\\/$Self->{'DB::QuoteBack'}\\/g;
+        }
+        if ($Self->{'DB::QuoteSingle'}) {
+            ${$Text} =~ s/'/$Self->{'DB::QuoteSingle'}'/g;
+        }
+        if ($Self->{'DB::QuoteSemicolon'}) {
+            ${$Text} =~ s/;/$Self->{'DB::QuoteSemicolon'};/g;
+        }
+    }
+    return $Text;
+}
+
 sub DatabaseCreate {
     my $Self = shift;
     my %Param = @_;
@@ -241,11 +273,24 @@ sub TableAlter {
         elsif ($Tag->{Tag} eq 'ColumnChange' && $Tag->{TagType} eq 'Start') {
             # Type translation
             $Tag = $Self->_TypeTranslation($Tag);
-            # normal data type
-            my $SQLEnd = $SQLStart." CHANGE $Tag->{NameOld} $Tag->{NameNew} $Tag->{Type}";
+            # rename oldname to newname
+            if ($Tag->{NameOld} ne $Tag->{NameNew}) {
+                push (@SQL, $SQLStart." RENAME COLUMN $Tag->{NameOld} TO $Tag->{NameNew}");
+            }
+            # alter table tabname modify
+            if (!$Tag->{Name} && $Tag->{NameNew}) {
+                $Tag->{Name} = $Tag->{NameNew};
+            }
+            if (!$Tag->{Name} && $Tag->{NameOld}) {
+                $Tag->{Name} = $Tag->{NameOld};
+            }
+            my $SQLEnd = $SQLStart." MODIFY $Tag->{Name} $Tag->{Type}";
             if ($Tag->{Required} && $Tag->{Required} =~ /^true$/i) {
                 $SQLEnd .= " NOT NULL";
             }
+            else {
+                $SQLEnd .= " NULL";
+            }
             # auto increment
             if ($Tag->{AutoIncrement} && $Tag->{AutoIncrement} =~ /^true$/i) {
                 $SQLEnd .= " AUTO_INCREMENT";
@@ -395,13 +440,13 @@ sub Insert {
             $SQL = "INSERT INTO $Tag->{Table} "
         }
         if ($Tag->{Tag} eq 'Data' && $Tag->{TagType} eq 'Start') {
-            $Tag->{Key} = $Self->Quote($Tag->{Key});
+            $Tag->{Key} = ${$Self->Quote(\$Tag->{Key})};
             push (@Keys, $Tag->{Key});
             if ($Tag->{Type} && $Tag->{Type} eq 'Quote') {
-                $Tag->{Value} = "'".$Self->Quote($Tag->{Value})."'";
+                $Tag->{Value} = "'".${$Self->Quote(\$Tag->{Value})}."'";
             }
             else {
-                $Tag->{Value} = $Self->Quote($Tag->{Value});
+                $Tag->{Value} = ${$Self->Quote(\$Tag->{Value})};
             }
             push (@Values, $Tag->{Value});
         }
@@ -454,4 +499,5 @@ sub _TypeTranslation {
     }
     return $Tag;
 }
+
 1;
